pub struct StandardScaler {
pub with_mean: bool,
pub with_std: bool,
}Expand description
Parameters for StandardScaler (unfitted state).
Standardizes features by removing the mean and scaling to unit variance:
z = (x - mean) / std
Fields
with_mean: boolIf true, center data to zero mean before scaling.
with_std: boolIf true, scale data to unit variance.
Implementations